import type { ISession } from 'myst-cli-utils';
import type { DownloadResult, ResolutionOptions } from './types.js';
/**
 * Attempt to download JATS from provided input
 *
 * `urlOrDoi` may be (1) a local file, in which case, the file content is
 * directly returned, (2) PubMed ID, PubMed Central ID, or DOI, in which case,
 * possible download links are constructed and followed, or (3) a direct
 * download URL, in which case, the content is fetched.
 */
export declare function downloadJatsFromUrl(session: ISession, urlOrDoi: string, opts?: ResolutionOptions): Promise<DownloadResult>;
/**
 * Given an input url/doi/identifier, attempt to download JATS XML and, optionally, dependent data
 *
 * Allowed inputs are DOI, PMCID, PubMed ID (which will be resolved to PMCID), or a direct JATS download URL
 *
 * `output` may be a destination folder or xml filename. If `data` is `true`, this function will also
 * attempt to fetch dependent data; currently, this flag is only supported for open-access PMC articles.
 * Data location will be determined using the pubmed OA API. You may also specify a `listing` file to look up
 * data location.
 */
export declare function jatsFetch(session: ISession, input: string, opts: {
    output?: string;
    data?: boolean;
    listing?: string;
}): Promise<void>;
//# sourceMappingURL=download.d.ts.map