import { doi } from 'doi-utils';
import fetch from 'node-fetch';
export const elife = {
    test(url) {
        return new URL(url).hostname === 'elifesciences.org';
    },
    jatsUrl(url) {
        return `${url}.xml`;
    },
};
export const plos = {
    test(url) {
        return new URL(url).hostname === 'journals.plos.org';
    },
    jatsUrl(url) {
        return url.replace('/article?', '/article/file?') + '&type=manuscript';
    },
};
export const joss = {
    test(url) {
        return new URL(url).hostname === 'joss.theoj.org' && doi.validate(url);
    },
    jatsUrl(url) {
        // Probably a better way to do this, the joss papers are on github!
        const doiString = doi.normalize(url);
        const [org, jossId] = doiString.split('/');
        const id = jossId.split('.')[1];
        return `https://raw.githubusercontent.com/openjournals/joss-papers/master/joss.${id}/${org}.${jossId}.jats`;
    },
};
export const DEFAULT_RESOLVERS = [elife, plos, joss];
/**
 * Use the known custom resolvers to pick where the JATS should be downloaded from.
 */
export async function customResolveJatsUrlFromDoi(session, doiString, opts = { resolvers: DEFAULT_RESOLVERS }) {
    var _a, _b;
    if (!doi.validate(doiString))
        throw new Error(`The doi ${doiString} is not valid`);
    const doiUrl = doi.buildUrl(doiString);
    session.log.debug(`Resolving DOI ${doiUrl}`);
    const resp = await ((_a = opts === null || opts === void 0 ? void 0 : opts.fetcher) !== null && _a !== void 0 ? _a : fetch)(doiUrl);
    const articleUrl = resp.url;
    session.log.debug(`Found resolved URL for DOI at ${articleUrl}`);
    const resolver = (_b = opts === null || opts === void 0 ? void 0 : opts.resolvers) === null || _b === void 0 ? void 0 : _b.find((r) => r.test(articleUrl));
    if (!resolver)
        throw new Error(`Could not resolve JATS for ${articleUrl}, no resolver matched`);
    const jatsUrl = resolver.jatsUrl(articleUrl);
    return jatsUrl;
}
